import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk.aws_lambda._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-lambda-layer-wget",
    "1.0.274",
    __name__[0:-6],
    "cdk-lambda-layer-wget@1.0.274.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
